==> KidozSDK-0.7.0-sources.jar: com/kidoz/sdk/api/ui_views/html_view/HtmlFiveWebView.java <==
package com.kidoz.sdk.api.ui_views.html_view;

import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.os.Build;
import android.util.AttributeSet;
import android.view.View;
import android.webkit.CookieManager;
import android.webkit.WebSettings;
import android.webkit.WebView;

import com.kidoz.sdk.api.general.utils.ConstantDef;
import com.kidoz.sdk.api.players.web_player.WebPreferenceConstants;

import org.json.JSONObject;

public class HtmlFiveWebView extends WebView
{
    public HtmlFiveWebView(Context context, AttributeSet attrs)
    {
        super(context, attrs);
        //initWebView(context);
        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
    }

    public HtmlFiveWebView(Context context)
    {
        super(context);

        try
        {
            initWebView(context);
        } catch (Exception e)
        {
        }

        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
    }

    public HtmlFiveWebView(Context context, boolean flag)
    {
        super(context);
        initWorkingSettingsForVideoInWebView();
    }

    private void initWorkingSettingsForVideoInWebView()
    {
        getSettings().setJavaScriptEnabled(true);

        // Enable cockies
        CookieManager.getInstance().setAcceptCookie(true);
        if (Build.VERSION.SDK_INT >= 21)
        {
            android.webkit.CookieManager.getInstance().setAcceptThirdPartyCookies(this, true);
        }

        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
        setDrawingCacheBackgroundColor(0x00000000);
        setBackgroundColor(Color.argb(1, 0, 0, 0));
        setFocusableInTouchMode(true);
        setFocusable(true);
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.M)
        {
            setAnimationCacheEnabled(true);
        }
        //setDrawingCacheEnabled(true);
        if (Build.VERSION.SDK_INT < 19)
        {
            getSettings().setDatabasePath(getContext().getCacheDir() + "/databases");
        }
        getSettings().setAppCacheEnabled(true);
        getSettings().setDatabaseEnabled(true);

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setAppCacheMaxSize(Long.MAX_VALUE);
        }
        if (Build.VERSION.SDK_INT < 17)
        {
            getSettings().setEnableSmoothTransition(true);
        }

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setRenderPriority(WebSettings.RenderPriority.HIGH);
        }
        getSettings().setBuiltInZoomControls(false);
        getSettings().setDisplayZoomControls(false);
        getSettings().setGeolocationDatabasePath(getContext().getFilesDir().toString());
        getSettings().setAppCachePath(getContext().getCacheDir().toString());
        getSettings().setAllowContentAccess(false);
        getSettings().setDefaultTextEncodingName("utf-8");
        getSettings().setUserAgentString("Mozilla/5.0 (Linux; Android 5.1; Nexus 4 Build/KRT16H) AppleWebKit/537.36(KHTML, like Gecko) Version/4.0 Chrome/30.0.0.0 Mobile Safari/537.36");
        getSettings().setGeolocationEnabled(true);
        getSettings().setSupportMultipleWindows(false);
        getSettings().setJavaScriptEnabled(true);
        getSettings().setJavaScriptCanOpenWindowsAutomatically(true);
        getSettings().setBlockNetworkImage(false);

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setSavePassword(false);
            getSettings().setPluginState(WebSettings.PluginState.ON);
        }
        if (Build.VERSION.SDK_INT >= 17)
        {
            getSettings().setMediaPlaybackRequiresUserGesture(false);
        }
        getSettings().setDomStorageEnabled(true);
        getSettings().setAllowFileAccess(true);
        getSettings().setSupportZoom(false);
        if (Build.VERSION.SDK_INT >= 16)
        {
            getSettings().setAllowFileAccessFromFileURLs(true);
            getSettings().setAllowUniversalAccessFromFileURLs(true);
        }
        getSettings().setSaveFormData(false);
        getSettings().setLoadWithOverviewMode(false);
        getSettings().setUseWideViewPort(false);
        getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);
        if (Build.VERSION.SDK_INT >= 16)
        {
            setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }
        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
        getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NORMAL);
        if (Build.VERSION.SDK_INT >= 19)
        {
            setWebContentsDebuggingEnabled(ConstantDef.DGM);
        }
        if (Build.VERSION.SDK_INT >= 17)
        {
            getSettings().setMediaPlaybackRequiresUserGesture(false);
        }
    }

    private void initWebView(Context context)
    {
        if (Build.VERSION.SDK_INT >= 19)
        {
            setWebContentsDebuggingEnabled(ConstantDef.DGM);
        }
        setDrawingCacheBackgroundColor(0x00000000);
        setBackgroundColor(Color.argb(1, 0, 0, 0));

        setFocusableInTouchMode(true);
        setFocusable(true);

        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.M)
        {
            setAnimationCacheEnabled(true);
        }
        //setDrawingCacheEnabled(true);

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN)
        {
            setBackground(null);
            getRootView().setBackground(null);
        } else
        {
            getRootView().setBackgroundDrawable(null);
        }

        if (Build.VERSION.SDK_INT < 19)
        {
            String databasePath = context.getDir("database", Context.MODE_PRIVATE).getPath();
            getSettings().setDatabasePath(databasePath);
        }

        getSettings().setAppCacheEnabled(true);
        getSettings().setDatabaseEnabled(true);

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setAppCacheMaxSize(Long.MAX_VALUE);
        }
        if (Build.VERSION.SDK_INT < 17)
        {
            getSettings().setEnableSmoothTransition(true);
        }

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setRenderPriority(WebSettings.RenderPriority.HIGH);
        }

        getSettings().setBuiltInZoomControls(false);
        getSettings().setDisplayZoomControls(false);
        getSettings().setGeolocationDatabasePath(context.getFilesDir().toString());
        getSettings().setAppCachePath(context.getCacheDir().toString());
        getSettings().setAllowContentAccess(false);
        getSettings().setDefaultTextEncodingName("utf-8");
        getSettings().setUserAgentString("Mozilla/5.0 (Linux; Android 5.1; Nexus 4 Build/KRT16H) AppleWebKit/537.36(KHTML, like Gecko) Version/4.0 Chrome/30.0.0.0 Mobile Safari/537.36");
        getSettings().setGeolocationEnabled(true);
        getSettings().setSupportMultipleWindows(false);
        getSettings().setJavaScriptEnabled(true);
        getSettings().setJavaScriptCanOpenWindowsAutomatically(true);
        getSettings().setBlockNetworkImage(false);

        SharedPreferences mPreferences = context.getSharedPreferences(WebPreferenceConstants.PREFERENCES, 0);
        if (Build.VERSION.SDK_INT < 18)
        {
            switch (mPreferences.getInt(WebPreferenceConstants.ADOBE_FLASH_SUPPORT, 0))
            {
                case 0:
                    getSettings().setPluginState(WebSettings.PluginState.OFF);
                    break;
                case 1:
                    getSettings().setPluginState(WebSettings.PluginState.ON_DEMAND);
                    break;
                case 2:
                    getSettings().setPluginState(WebSettings.PluginState.ON);
                    break;
                default:
                    break;
            }
        }

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setSavePassword(false);
        }

        //*********************************************************************//
        applyProperties(new JSONObject());

        if (Build.VERSION.SDK_INT >= 17)
        {
            getSettings().setMediaPlaybackRequiresUserGesture(false);
        }

        getSettings().setDomStorageEnabled(true);
        getSettings().setAllowFileAccess(true);
        getSettings().setSupportZoom(false);
        if (Build.VERSION.SDK_INT >= 16)
        {
            getSettings().setAllowFileAccessFromFileURLs(true);
            getSettings().setAllowUniversalAccessFromFileURLs(true);
        }
        getSettings().setSaveFormData(false);
        getSettings().setLoadWithOverviewMode(false);
        getSettings().setUseWideViewPort(false);
        getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);

        if (Build.VERSION.SDK_INT >= 16)
        {
            setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }

        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }

        //*********************************************************************//

        if (mPreferences.getBoolean(WebPreferenceConstants.TEXT_REFLOW, false))
        {
            getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NARROW_COLUMNS);
        } else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT)
        {
            try
            {
                getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.TEXT_AUTOSIZING);
            } catch (IllegalArgumentException e)
            {
                getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NORMAL);
            }
        } else
        {
            getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NORMAL);
        }
    }

    public synchronized void stopAndReleaseWebView()
    {
        loadUrl("");
        stopLoading();
        clearHistory();
        removeAllViews();
        destroyDrawingCache();
    }

    /**
     * Set and apply webview properties defined in the passed JSON object
     */
    public void applyProperties(JSONObject properties)
    {
        if (properties != null)
        {
            if (Build.VERSION.SDK_INT >= 17)
            {
                getSettings().setMediaPlaybackRequiresUserGesture(properties.optBoolean("setMediaPlaybackRequiersGesture", false));
            }

            getSettings().setDomStorageEnabled(properties.optBoolean("setDomStorageEnabled", true));
            getSettings().setAllowFileAccess(properties.optBoolean("setAllowFileAccess", true));
            getSettings().setSupportZoom(properties.optBoolean("setZoomSupport", false));
            if (Build.VERSION.SDK_INT >= 16)
            {
                getSettings().setAllowFileAccessFromFileURLs(properties.optBoolean("setAllowFileAccessFromFileUrls", true));
                getSettings().setAllowUniversalAccessFromFileURLs(properties.optBoolean("setAllowUniversalAccessFromFileURLs", true));

                if (properties.optBoolean("setHardwareAcceleration", true))
                {
                    setLayerType(View.LAYER_TYPE_HARDWARE, null);
                } else
                {
                    setLayerType(View.LAYER_TYPE_SOFTWARE, null);
                }
            }
            getSettings().setSaveFormData(properties.optBoolean("setSaveFormData", false));
            getSettings().setLoadWithOverviewMode(properties.optBoolean("setLoadWithOverviewMode", false));
            getSettings().setUseWideViewPort(properties.optBoolean("setUseWideViewPort", false));
            getSettings().setCacheMode(properties.optInt("setCacheMode", WebSettings.LOAD_NO_CACHE));

            if (properties.has("setBackgroundColor"))
            {
                try
                {
                    setBackgroundColor(Color.argb(1, 0, 0, 0));
                } catch (Exception e)
                {
                }
            }
        }

        setBackgroundColor(Color.argb(1, 0, 0, 0));
    }
}

==> KidozSDK-0.7.1-sources.jar: com/kidoz/sdk/api/ui_views/html_view/HtmlFiveWebView.java <==
package com.kidoz.sdk.api.ui_views.html_view;

import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.os.Build;
import android.util.AttributeSet;
import android.view.View;
import android.webkit.CookieManager;
import android.webkit.WebSettings;
import android.webkit.WebView;

import com.kidoz.sdk.api.general.utils.ConstantDef;
import com.kidoz.sdk.api.players.web_player.WebPreferenceConstants;

import org.json.JSONObject;

public class HtmlFiveWebView extends WebView
{
    public HtmlFiveWebView(Context context, AttributeSet attrs)
    {
        super(context, attrs);
        //initWebView(context);
        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
    }

    public HtmlFiveWebView(Context context)
    {
        super(context);

        try
        {
            initWebView(context);
        }
        catch (Exception e)
        {
        }

        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
    }

    public HtmlFiveWebView(Context context, boolean flag)
    {
        super(context);
        initWorkingSettingsForVideoInWebView();
    }

    private void initWorkingSettingsForVideoInWebView()
    {
        getSettings().setJavaScriptEnabled(true);

        // Enable cockies
        CookieManager.getInstance().setAcceptCookie(true);
        if (Build.VERSION.SDK_INT >= 21)
        {
            android.webkit.CookieManager.getInstance().setAcceptThirdPartyCookies(this, true);
        }

        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
        setDrawingCacheBackgroundColor(0x00000000);
        setBackgroundColor(Color.argb(1, 0, 0, 0));
        setFocusableInTouchMode(true);
        setFocusable(true);
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.M)
        {
            setAnimationCacheEnabled(true);
        }
        //setDrawingCacheEnabled(true);
        if (Build.VERSION.SDK_INT < 19)
        {
            getSettings().setDatabasePath(getContext().getCacheDir() + "/databases");
        }
        getSettings().setAppCacheEnabled(true);
        getSettings().setDatabaseEnabled(true);

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setAppCacheMaxSize(Long.MAX_VALUE);
        }
        if (Build.VERSION.SDK_INT < 17)
        {
            getSettings().setEnableSmoothTransition(true);
        }

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setRenderPriority(WebSettings.RenderPriority.HIGH);
        }
        getSettings().setBuiltInZoomControls(false);
        getSettings().setDisplayZoomControls(false);
        getSettings().setGeolocationDatabasePath(getContext().getFilesDir().toString());
        getSettings().setAppCachePath(getContext().getCacheDir().toString());
        getSettings().setAllowContentAccess(false);
        getSettings().setDefaultTextEncodingName("utf-8");
        getSettings().setUserAgentString(ConstantDef.USER_AGENT);
        getSettings().setGeolocationEnabled(true);
        getSettings().setSupportMultipleWindows(false);
        getSettings().setJavaScriptEnabled(true);
        getSettings().setJavaScriptCanOpenWindowsAutomatically(true);
        getSettings().setBlockNetworkImage(false);

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setSavePassword(false);
            getSettings().setPluginState(WebSettings.PluginState.ON);
        }
        if (Build.VERSION.SDK_INT >= 17)
        {
            getSettings().setMediaPlaybackRequiresUserGesture(false);
        }
        getSettings().setDomStorageEnabled(true);
        getSettings().setAllowFileAccess(true);
        getSettings().setSupportZoom(false);
        if (Build.VERSION.SDK_INT >= 16)
        {
            getSettings().setAllowFileAccessFromFileURLs(true);
            getSettings().setAllowUniversalAccessFromFileURLs(true);
        }
        getSettings().setSaveFormData(false);
        getSettings().setLoadWithOverviewMode(false);
        getSettings().setUseWideViewPort(false);
        getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);
        if (Build.VERSION.SDK_INT >= 16)
        {
            setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }
        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
        getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NORMAL);
        if (Build.VERSION.SDK_INT >= 19)
        {
            setWebContentsDebuggingEnabled(ConstantDef.DGM);
        }
        if (Build.VERSION.SDK_INT >= 17)
        {
            getSettings().setMediaPlaybackRequiresUserGesture(false);
        }
    }

    private void initWebView(Context context)
    {
        if (Build.VERSION.SDK_INT >= 19)
        {
            setWebContentsDebuggingEnabled(ConstantDef.DGM);
        }
        setDrawingCacheBackgroundColor(0x00000000);
        setBackgroundColor(Color.argb(1, 0, 0, 0));

        setFocusableInTouchMode(true);
        setFocusable(true);

        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.M)
        {
            setAnimationCacheEnabled(true);
        }
        //setDrawingCacheEnabled(true);

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN)
        {
            setBackground(null);
            getRootView().setBackground(null);
        }
        else
        {
            getRootView().setBackgroundDrawable(null);
        }

        if (Build.VERSION.SDK_INT < 19)
        {
            String databasePath = context.getDir("database", Context.MODE_PRIVATE).getPath();
            getSettings().setDatabasePath(databasePath);
        }

        getSettings().setAppCacheEnabled(true);
        getSettings().setDatabaseEnabled(true);

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setAppCacheMaxSize(Long.MAX_VALUE);
        }
        if (Build.VERSION.SDK_INT < 17)
        {
            getSettings().setEnableSmoothTransition(true);
        }

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setRenderPriority(WebSettings.RenderPriority.HIGH);
        }

        getSettings().setBuiltInZoomControls(false);
        getSettings().setDisplayZoomControls(false);
        getSettings().setGeolocationDatabasePath(context.getFilesDir().toString());
        getSettings().setAppCachePath(context.getCacheDir().toString());
        getSettings().setAllowContentAccess(false);
        getSettings().setDefaultTextEncodingName("utf-8");
        getSettings().setUserAgentString(ConstantDef.USER_AGENT);
        getSettings().setGeolocationEnabled(true);
        getSettings().setSupportMultipleWindows(false);
        getSettings().setJavaScriptEnabled(true);
        getSettings().setJavaScriptCanOpenWindowsAutomatically(true);
        getSettings().setBlockNetworkImage(false);

        SharedPreferences mPreferences = context.getSharedPreferences(WebPreferenceConstants.PREFERENCES, 0);
        if (Build.VERSION.SDK_INT < 18)
        {
            switch (mPreferences.getInt(WebPreferenceConstants.ADOBE_FLASH_SUPPORT, 0))
            {
                case 0:
                    getSettings().setPluginState(WebSettings.PluginState.OFF);
                    break;
                case 1:
                    getSettings().setPluginState(WebSettings.PluginState.ON_DEMAND);
                    break;
                case 2:
                    getSettings().setPluginState(WebSettings.PluginState.ON);
                    break;
                default:
                    break;
            }
        }

        if (Build.VERSION.SDK_INT < 18)
        {
            getSettings().setSavePassword(false);
        }

        //*********************************************************************//
        applyProperties(new JSONObject());

        if (Build.VERSION.SDK_INT >= 17)
        {
            getSettings().setMediaPlaybackRequiresUserGesture(false);
        }

        getSettings().setDomStorageEnabled(true);
        getSettings().setAllowFileAccess(true);
        getSettings().setSupportZoom(false);
        if (Build.VERSION.SDK_INT >= 16)
        {
            getSettings().setAllowFileAccessFromFileURLs(true);
            getSettings().setAllowUniversalAccessFromFileURLs(true);
        }
        getSettings().setSaveFormData(false);
        getSettings().setLoadWithOverviewMode(false);
        getSettings().setUseWideViewPort(false);
        getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);

        if (Build.VERSION.SDK_INT >= 16)
        {
            setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }

        if (Build.VERSION.SDK_INT >= 21)
        {
            getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }

        //*********************************************************************//

        if (mPreferences.getBoolean(WebPreferenceConstants.TEXT_REFLOW, false))
        {
            getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NARROW_COLUMNS);
        }
        else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT)
        {
            try
            {
                getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.TEXT_AUTOSIZING);
            }
            catch (IllegalArgumentException e)
            {
                getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NORMAL);
            }
        }
        else
        {
            getSettings().setLayoutAlgorithm(WebSettings.LayoutAlgorithm.NORMAL);
        }
    }

    public synchronized void stopAndReleaseWebView()
    {
        loadUrl("");
        stopLoading();
        clearHistory();
        removeAllViews();
        destroyDrawingCache();
    }

    /**
     * Set and apply webview properties defined in the passed JSON object
     */
    public void applyProperties(JSONObject properties)
    {
        if (properties != null)
        {
            if (Build.VERSION.SDK_INT >= 17)
            {
                getSettings().setMediaPlaybackRequiresUserGesture(properties.optBoolean("setMediaPlaybackRequiersGesture", false));
            }

            getSettings().setDomStorageEnabled(properties.optBoolean("setDomStorageEnabled", true));
            getSettings().setAllowFileAccess(properties.optBoolean("setAllowFileAccess", true));
            getSettings().setSupportZoom(properties.optBoolean("setZoomSupport", false));
            if (Build.VERSION.SDK_INT >= 16)
            {
                getSettings().setAllowFileAccessFromFileURLs(properties.optBoolean("setAllowFileAccessFromFileUrls", true));
                getSettings().setAllowUniversalAccessFromFileURLs(properties.optBoolean("setAllowUniversalAccessFromFileURLs", true));

                if (properties.optBoolean("setHardwareAcceleration", true))
                {
                    setLayerType(View.LAYER_TYPE_HARDWARE, null);
                }
                else
                {
                    setLayerType(View.LAYER_TYPE_SOFTWARE, null);
                }
            }
            getSettings().setSaveFormData(properties.optBoolean("setSaveFormData", false));
            getSettings().setLoadWithOverviewMode(properties.optBoolean("setLoadWithOverviewMode", false));
            getSettings().setUseWideViewPort(properties.optBoolean("setUseWideViewPort", false));
            getSettings().setCacheMode(properties.optInt("setCacheMode", WebSettings.LOAD_NO_CACHE));

            if (properties.has("setBackgroundColor"))
            {
                try
                {
                    setBackgroundColor(Color.argb(1, 0, 0, 0));
                }
                catch (Exception e)
                {
                }
            }
        }

        setBackgroundColor(Color.argb(1, 0, 0, 0));
    }
}
